//
// RmfMaker.cc
//
// Authors:  Richard Saxton (VEGA/ESA)
//           ESA XMM SOC
//
// Description: Runs rmfgen to produce an ARF
//
#include <Tracer.h>
#include <metatask.h>
#include <errstr.h>
#include <param.h>

#include <rmfgen.h>   // tasks

#include "RmfMaker.h"

RmfMaker::RmfMaker(string spectrumset, string rmfset,
                  bool extendedsource)
{
  PROC;

  /* Set up the parameters for calling rmfgen */
    openParameters("rmfgen");

  /* First the input parameters */
    setParameter("spectrumset",spectrumset);
    setParameter("rmfset",rmfset);

  /* Set the other parameters */
    setParameter("withenergybins",false);
    setParameter("energymin",0.05);
    setParameter("energymax",12.0);
    setParameter("nenergybins",120);

    setParameter("extendedsource",extendedsource);
                                                                                
    if (extendedsource)
    {
       setParameter("detmaptype","flat");
    }
    else{
       setParameter("detmaptype","psf");
    }

  /* Now run rmfgen using these parameters */ 
    task(rmfgen);
   
  /* Shutdown */
    closeParameters();

  ENDPROC;
}

RmfMaker::~RmfMaker()
{
  PROC;
  ENDPROC;
}

